@@ -1,6 +1,6 @@
 from sphinx.util import requests
 import requests
-from diningcodeapi.config import HEADERS
+from diningcodeapi.config import HEADERS, API_VERSION_V1
 
 
 class DistrictMixin:
@@ -13,4 +13,5 @@ class DistrictMixin:
         response.raise_for_status()
         themes = response.json()
         themes['_id'] = 1
+        themes['api-version'] = API_VERSION_V1
         return themes
